@@ -315,6 +315,8 @@ def main(args):
     register_coco_instances(cfg.DATASETS.TEST[0], {},
                             cfg.DATASETS.TEST[1],
                             cfg.DATASETS.TEST[2])
+    cfg.DATASETS.TRAIN = ('train_dataset',)
+    cfg.DATASETS.TEST = ('test_dataset',)
     if args.eval_only:
         model = Trainer.build_model(cfg)
         DetectionCheckpointer(model, save_dir=cfg.OUTPUT_DIR).resume_or_load(
